#
# spec file for package python-django-rosetta
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-django-rosetta
Version:        0.9.9
Release:        1.3
Summary:        Django application that eases the translation of Django projects
License:        MIT
URL:            https://github.com/mbi/django-rosetta
Source:         https://files.pythonhosted.org/packages/source/d/django-rosetta/django-rosetta-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-Django >= 1.11
Requires:       python-polib >= 1.1.0
Requires:       python-requests >= 2.1.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module polib >= 1.1.0}
BuildRequires:  %{python_module pymemcache}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module requests >= 2.1.0}
BuildRequires:  %{python_module vcrpy}
BuildRequires:  memcached
# /SECTION
%python_subpackages

%description
Django application that eases the translation of Django projects.

%prep
%setup -q -n django-rosetta-%{version}
# Workaround https://github.com/mbi/django-rosetta/issues/233
sed -i 's/test_47_azure_ajax_translation/_test_47_azure_ajax_translation/' rosetta/tests/tests.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd testproject
%{_bindir}/memcached &
%python_exec -Wd manage.py test -v2 rosetta

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/rosetta
%{python_sitelib}/django_rosetta-%{version}*-info

%changelog
* Wed Apr 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.9:
  * Use packaged jQuery instead of the CDN version. (#274, thanks
    @stephanema1)
  * Test test_47_azure_ajax_translation: avoid DNS lookup for
    better isolation. Should fix #233
  * Adds Chinese (Simplified) translation. (#266 thanks
    @chenluyong)
  * Test against Django 4.1 and 4.2
  * Limit supported versions to Django 3.2 and later, using
    Python 3.8, 3.9 and 3.10
  * Proxy Deepl translations suggestions through the back-end to
    avoid CORS issues. (#271 thanks @rafaelromon, @biermeester
    and @matthiask)
  * Format code with pre-commit
  * Replace case sensitivity check with setting (#273 thanks
    @patroqueeet)
* Fri Dec 16 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded BuildRequires on python-python-memcached.
* Mon Nov 28 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove python_module macro definition
- More specific python_sitelib in %%files
- Remove python-six dependency
- Fix path to memcached in %%check
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.9.8
  * Test against Django 4.0
- from v0.9.7
  * Arabic translation
  * Translations via the DeepL API
  * Fixed unicode handling in gettext headers
  * Remove six as a dependency
  * Move context and comment hints into the right-most column
  * Add extra styles block to the base template
* Fri Jul 23 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v0.9.6
* Mon Apr 13 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.9.4
* Mon Apr 13 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v0.9.3
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 0.7.2
  + No changelog available
- Replace python-distribute with python-setuptools BuildRequires
- Add documentation from tarball
* Sat Mar  2 2013 alexandre@exatati.com.br
- Update to 0.7.1:
  * Fix: value missing in context
- Aditional changes from 0.7.0:
  * Support for Django 1.5 and HEAD, support for Python 3.
  * Upgraded bundled polib to version 1.0.3 -
    http://pypi.python.org/pypi/polib/1.0.3
  * Support timezones on the last modified PO header. Thanks
    @jmoiron (Issue #43)
  * Actually move to the next block when submitting a lot
    of translations (Issue #13)
  * Add msgctxt to the entry hash to differentiate entries with
    context. Thanks @metalpriest (Issue #39)
  * Better discovery of locale files on Django 1.4+ Thanks
    @tijs (Issues #63, #64)
  * List apps in alphabetical order
* Fri Jun  8 2012 aledr@exatati
- Update to 0.6.8:
  - Switched to a pluggable storage backend model to increase
    compatibility with Django 1.4. Cache and Session-based storages
    are provided.
- Aditional changes from 0.6.7:
  - Added a testproject to run tests
  - Updated french translation. Thanks, @BertrandBordage
  - Merged @sleepyjames' PR that fixes an error when pofile save
    path contains '.po' in the path
  - Merged @rory's PR to correcty handle plural strings that have
    a leading/trailing newline (Issue #34)
- Reworked spec file with py2pack.
* Tue Mar 27 2012 alexandre@exatati.com.br
- Update to 0.6.6:
  * Django 1.4 support (Issue #30, #33)
  * Better handling of translation callbacks on Bing's translation
    API and support of composite locales (Issue #26)
* Sat Jan 28 2012 alexandre@exatati.com.br
- Update to 0.6.5:
  - Updated polib to 0.7.0
  - Added ROSETTA_POFILE_WRAP_WIDTH setting to track the line-length
    of the updated Po file. (Issue #24)
  - Renamed the messages context variable to rosetta_messages prevent
    conflicts with django.contrib.messages (Issue #23)
- Aditional changes from 0.6.4:
  - Added ROSETTA_REQUIRES_AUTH option to grant access to non
    authenticated users (False by default).
* Fri Jan  6 2012 alexandre@exatati.com.br
- Update to 0.6.3:
  - Sorry, no changelog.
- Remove CFLAGS and %%clean section from spec file.
* Thu Jun 16 2011 alexandre@exatati.com.br
- Update to 0.6.2;
- Replace python-setuptools by python-distribute in spec file.
* Wed Mar 23 2011 alexandre@exatati.com.br
- Update to 0.6.0;
- Regenerated spec file with py2pack.
* Wed Jul  7 2010 alexandre@exatati.com.br
- Update to 0.5.6.
* Sat Jun  5 2010 alexandre@exatati.com.br
- Update to 0.5.5;
- Spec file cleaned with spec-cleaner.
* Thu Feb 25 2010 alexandre@exatati.com.br
- Update to 0.5.3.
* Sat Jan 23 2010 alexandre@exatati.com.br
- Update to 0.5.2.
* Fri Nov 27 2009 alexandre@exatati.com.br
- Update to 0.5.1.
* Wed Oct 21 2009 alexandre@exatati.com.br
- Update to 0.4.9.
* Mon Oct 19 2009 alexandre@exatati.com.br
- Update to 0.4.8.
* Wed Sep 23 2009 alexandre@exatati.com.br
- Update to 0.4.7;
- Building as noarch for openSUSE >= 11.2.
* Mon Sep 21 2009 alexandre@exatati.com.br
- Initial package (0.4.6.svn).
